pyxmpp2.settings

Package pyxmpp2 :: Module settings |
[hide private]

# Module settings

General settings container.

The behaviour of the XMPP implementation may be controlled by many, many parameters, like addresses, authetication methods, TLS settings, keep alive, etc. Those need to be passed from one component to other and passing it directly via function parameters would only mess up the API.

Instead an XMPPSettings object will be used to pass all the optional parameters. It will also provide the defaults.

This is also a mechanism for dependency injection, allowing different components share the same objects, like event queue or DNS resolver implementation.

Classes | [hide private]
| _SettingDefinition A PyXMPP2 setting meta-data and defaults.
| XMPPSettings Container for various parameters used all over PyXMPP.
| _YesNoAction Custom std:argparse option to handle boolean options via '--no-' prefixes.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.settings")`